Documentation
¶
Index ¶
- Constants
- func GetGitHash() string
- func GetSpecifiedRegion() string
- func LastCacheUpdate() time.Time
- func LastCacheUpdateVersion() string
- func LoadEscortState(accountID uint32) ([]*protobuf.ESCORT_INFO, error)
- func ResolveRegionVersion(region string) (string, error)
- func UpdateAllData(region string)
- func UpdateEscortTimestamps(accountID uint32, lineID uint32, awardTS uint32, flashTS uint32) error
- type EscortConfig
- type EscortMapTemplate
- type EscortTemplate
- type Field
- type GameChecksum
- type HashMap
- type Version
- type VersionMap
Constants ¶
const ( // region / file URL_BASE = "https://raw.githubusercontent.com/ggmolly/belfast-data/main/%s/%s" REGIONLESS_URL_BASE = "https://raw.githubusercontent.com/ggmolly/belfast-data/main/%s" )
Variables ¶
This section is empty.
Functions ¶
func GetSpecifiedRegion ¶
func GetSpecifiedRegion() string
GetSpecifiedRegion returns the value of the environment variable AL_REGION it is needed for the web UI to highlight the correct region since we cannot call os.Getenv from the web template engine ¯\_(ツ)_/¯
func LastCacheUpdate ¶
func LastCacheUpdateVersion ¶
func LastCacheUpdateVersion() string
func LoadEscortState ¶
func LoadEscortState(accountID uint32) ([]*protobuf.ESCORT_INFO, error)
func ResolveRegionVersion ¶
func UpdateAllData ¶
func UpdateAllData(region string)
Types ¶
type EscortConfig ¶
type EscortConfig struct {
Templates map[uint32]EscortTemplate
Maps []EscortMapTemplate
}
func GetEscortConfig ¶
func GetEscortConfig() (*EscortConfig, error)
type EscortMapTemplate ¶
type EscortMapTemplate struct {
ID uint32 `json:"id"`
RefreshTime uint32 `json:"refresh_time"`
DropByWarn []uint32 `json:"drop_by_warn"`
EscortIDList json.RawMessage `json:"escort_id_list"`
}
type EscortTemplate ¶
type EscortTemplate struct {
ID uint32 `json:"id"`
GardroadReward json.RawMessage `json:"gardroad_reward"`
}
type Field ¶
func GetPacketFields ¶
type GameChecksum ¶
type HashMap ¶
type HashMap []GameChecksum
func GetGameHashes ¶
func GetGameHashes() HashMap
func GetGameHashesWithUpdate ¶
func GetGameHashesWithUpdate() HashMap
type VersionMap ¶
func GetLatestVersions ¶
func GetLatestVersions() VersionMap
Click to show internal directories.
Click to hide internal directories.